@@ -20,19 +20,17 @@
 #ifndef BTFUNCTIONS_H
 #define BTFUNCTIONS_H
 
-
-#include <ktorrent_export.h>
-#include <QString>
 #include "constants.h"
-
+#include <QString>
+#include <ktorrent_export.h>
 
 namespace bt
 {
 struct TorrentStats;
 
-KTORRENT_EXPORT double Percentage(const TorrentStats & s);
+KTORRENT_EXPORT double Percentage(const TorrentStats &s);
 
-inline void WriteUint64(Uint8* buf, Uint32 off, Uint64 val)
+inline void WriteUint64(Uint8 *buf, Uint32 off, Uint64 val)
 {
     buf[off + 0] = (Uint8)((val & 0xFF00000000000000ULL) >> 56);
     buf[off + 1] = (Uint8)((val & 0x00FF000000000000ULL) >> 48);
@@ -44,22 +42,15 @@ inline void WriteUint64(Uint8* buf, Uint32 off, Uint64 val)
     buf[off + 7] = (Uint8)((val & 0x00000000000000FFULL) >> 0);
 }
 
-inline Uint64 ReadUint64(const Uint8* buf, Uint64 off)
+inline Uint64 ReadUint64(const Uint8 *buf, Uint64 off)
 {
-    Uint64 tmp =
-        ((Uint64)buf[off] << 56) |
-        ((Uint64)buf[off + 1] << 48) |
-        ((Uint64)buf[off + 2] << 40) |
-        ((Uint64)buf[off + 3] << 32) |
-        ((Uint64)buf[off + 4] << 24) |
-        ((Uint64)buf[off + 5] << 16) |
-        ((Uint64)buf[off + 6] << 8) |
-        ((Uint64)buf[off + 7] << 0);
+    Uint64 tmp = ((Uint64)buf[off] << 56) | ((Uint64)buf[off + 1] << 48) | ((Uint64)buf[off + 2] << 40) | ((Uint64)buf[off + 3] << 32)
+        | ((Uint64)buf[off + 4] << 24) | ((Uint64)buf[off + 5] << 16) | ((Uint64)buf[off + 6] << 8) | ((Uint64)buf[off + 7] << 0);
 
     return tmp;
 }
 
-inline void WriteUint32(Uint8* buf, Uint32 off, Uint32 val)
+inline void WriteUint32(Uint8 *buf, Uint32 off, Uint32 val)
 {
     buf[off + 0] = (Uint8)((val & 0xFF000000) >> 24);
     buf[off + 1] = (Uint8)((val & 0x00FF0000) >> 16);
@@ -67,24 +58,23 @@ inline void WriteUint32(Uint8* buf, Uint32 off, Uint32 val)
     buf[off + 3] = (Uint8)(val & 0x000000FF);
 }
 
-inline Uint32 ReadUint32(const Uint8* buf, Uint32 off)
+inline Uint32 ReadUint32(const Uint8 *buf, Uint32 off)
 {
     return (buf[off] << 24) | (buf[off + 1] << 16) | (buf[off + 2] << 8) | buf[off + 3];
 }
 
-inline void WriteUint16(Uint8* buf, Uint32 off, Uint16 val)
+inline void WriteUint16(Uint8 *buf, Uint32 off, Uint16 val)
 {
     buf[off + 0] = (Uint8)((val & 0xFF00) >> 8);
     buf[off + 1] = (Uint8)(val & 0x000FF);
 }
 
-inline Uint16 ReadUint16(const Uint8* buf, Uint32 off)
+inline Uint16 ReadUint16(const Uint8 *buf, Uint32 off)
 {
     return (buf[off] << 8) | buf[off + 1];
 }
 
-
-inline void WriteInt64(Uint8* buf, Uint32 off, Int64 val)
+inline void WriteInt64(Uint8 *buf, Uint32 off, Int64 val)
 {
     buf[off + 0] = (Uint8)((val & 0xFF00000000000000ULL) >> 56);
     buf[off + 1] = (Uint8)((val & 0x00FF000000000000ULL) >> 48);
@@ -96,22 +86,15 @@ inline void WriteInt64(Uint8* buf, Uint32 off, Int64 val)
     buf[off + 7] = (Uint8)((val & 0x00000000000000FFULL) >> 0);
 }
 
-inline Int64 ReadInt64(const Uint8* buf, Uint32 off)
+inline Int64 ReadInt64(const Uint8 *buf, Uint32 off)
 {
-    Int64 tmp =
-        ((Int64)buf[off] << 56) |
-        ((Int64)buf[off + 1] << 48) |
-        ((Int64)buf[off + 2] << 40) |
-        ((Int64)buf[off + 3] << 32) |
-        ((Int64)buf[off + 4] << 24) |
-        ((Int64)buf[off + 5] << 16) |
-        ((Int64)buf[off + 6] << 8) |
-        ((Int64)buf[off + 7] << 0);
+    Int64 tmp = ((Int64)buf[off] << 56) | ((Int64)buf[off + 1] << 48) | ((Int64)buf[off + 2] << 40) | ((Int64)buf[off + 3] << 32) | ((Int64)buf[off + 4] << 24)
+        | ((Int64)buf[off + 5] << 16) | ((Int64)buf[off + 6] << 8) | ((Int64)buf[off + 7] << 0);
 
     return tmp;
 }
 
-inline void WriteInt32(Uint8* buf, Uint32 off, Int32 val)
+inline void WriteInt32(Uint8 *buf, Uint32 off, Int32 val)
 {
     buf[off + 0] = (Uint8)((val & 0xFF000000) >> 24);
     buf[off + 1] = (Uint8)((val & 0x00FF0000) >> 16);
@@ -119,18 +102,18 @@ inline void WriteInt32(Uint8* buf, Uint32 off, Int32 val)
     buf[off + 3] = (Uint8)(val & 0x000000FF);
 }
 
-inline Int32 ReadInt32(const Uint8* buf, Uint32 off)
+inline Int32 ReadInt32(const Uint8 *buf, Uint32 off)
 {
     return (Int32)(buf[off] << 24) | (buf[off + 1] << 16) | (buf[off + 2] << 8) | buf[off + 3];
 }
 
-inline void WriteInt16(Uint8* buf, Uint32 off, Int16 val)
+inline void WriteInt16(Uint8 *buf, Uint32 off, Int16 val)
 {
     buf[off + 0] = (Uint8)((val & 0xFF00) >> 8);
     buf[off + 1] = (Uint8)(val & 0x000FF);
 }
 
-inline Int16 ReadInt16(const Uint8* buf, Uint32 off)
+inline Int16 ReadInt16(const Uint8 *buf, Uint32 off)
 {
     return (Int16)(buf[off] << 8) | buf[off + 1];
 }
@@ -147,7 +130,7 @@ inline TimeStamp CurrentTime()
 KTORRENT_EXPORT TimeStamp Now();
 
 KTORRENT_EXPORT QString DirSeparator();
-KTORRENT_EXPORT bool IsMultimediaFile(const QString & filename);
+KTORRENT_EXPORT bool IsMultimediaFile(const QString &filename);
 
 /**
  * Maximize the file and memory limits using setrlimit.
@@ -164,16 +147,16 @@ KTORRENT_EXPORT Uint32 CurrentOpenFiles();
 KTORRENT_EXPORT bool OpenFileAllowed();
 
 /// Set the network interface to use (null means all interfaces)
-KTORRENT_EXPORT void SetNetworkInterface(const QString & iface);
+KTORRENT_EXPORT void SetNetworkInterface(const QString &iface);
 
 /// Get the network interface which needs to be used (this will return the name e.g. eth0, wlan0 ...)
 KTORRENT_EXPORT QString NetworkInterface();
 
 /// Get the IP address of the network interface
-KTORRENT_EXPORT QString NetworkInterfaceIPAddress(const QString & iface);
+KTORRENT_EXPORT QString NetworkInterfaceIPAddress(const QString &iface);
 
 /// Get all the IP addresses of the network interface
-KTORRENT_EXPORT QStringList NetworkInterfaceIPAddresses(const QString & iface);
+KTORRENT_EXPORT QStringList NetworkInterfaceIPAddresses(const QString &iface);
 
 /// Get the current IPv6 address
 KTORRENT_EXPORT QString CurrentIPv6Address();
@@ -202,9 +185,10 @@ template<class T> QString hex(T val)
 }
 
 struct KTORRENT_EXPORT RecursiveEntryGuard {
-    bool* guard;
+    bool *guard;
 
-    RecursiveEntryGuard(bool* g) : guard(g)
+    RecursiveEntryGuard(bool *g)
+        : guard(g)
     {
         *guard = true;
     }
