@@ -18,33 +18,31 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.             *
  ***************************************************************************/
 #include "sha1hashgen.h"
+#include "functions.h"
+#include <QtCrypto>
+#include <arpa/inet.h>
 #include <stdio.h>
 #include <string.h>
-#include <arpa/inet.h>
-#include <QtCrypto>
-#include "functions.h"
-
-
 
 namespace bt
 {
 static QCA::Initializer qca_init;
 
-SHA1HashGen::SHA1HashGen() : h(new QCA::Hash(QStringLiteral("sha1")))
+SHA1HashGen::SHA1HashGen()
+    : h(new QCA::Hash(QStringLiteral("sha1")))
 {
     memset(result, 9, 20);
 }
 
-
 SHA1HashGen::~SHA1HashGen()
 {
     delete h;
 }
 
-SHA1Hash SHA1HashGen::generate(const Uint8* data, Uint32 len)
+SHA1Hash SHA1HashGen::generate(const Uint8 *data, Uint32 len)
 {
-    h->update((const char*)data, len);
-    return SHA1Hash((const bt::Uint8*)h->final().constData());
+    h->update((const char *)data, len);
+    return SHA1Hash((const bt::Uint8 *)h->final().constData());
 }
 
 void SHA1HashGen::start()
@@ -52,18 +50,16 @@ void SHA1HashGen::start()
     h->clear();
 }
 
-void SHA1HashGen::update(const Uint8* data, Uint32 len)
+void SHA1HashGen::update(const Uint8 *data, Uint32 len)
 {
-    h->update((const char*)data, len);
+    h->update((const char *)data, len);
 }
 
-
 void SHA1HashGen::end()
 {
     memcpy(result, h->final().constData(), 20);
 }
 
-
 SHA1Hash SHA1HashGen::get() const
 {
     return SHA1Hash(result);
